==> haskell-path-pieces-0.2.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-AZk0EGu6V6T5oUmwMyuOLk
key: path-pieces-0.2.1-AZk0EGu6V6T5oUmwMyuOLk
license: BSD3
maintainer: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
indefinite: False
exposed-modules:
    Web.PathPieces
abi: 1faa2fd961cd282702338705726a412e
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-AZk0EGu6V6T5oUmwMyuOLk
depends:
    base-4.10.1.0 text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj time-1.8.0.2
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             text-1.2.3.0-FxgEmn4RjqC37dwdnPGDhj=d51c5ac73448d7d6c9cbe4dedb95457e
             time-1.8.0.2=7cc0324e0aef789d5f0780f6640c241b
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-pieces-0.2.1-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-pieces.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-pieces
version: 0.2.1
id: path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
key: path-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
license: BSD-3-Clause
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: unstable
synopsis: Components of paths.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/path-pieces>.
category: Web, Yesod
abi: 1166181b3a856c142b70fd4b4becff57
exposed: True
exposed-modules:
    Web.PathPieces
import-dirs: /usr/lib/ghc-8.4.2/site-local/path-pieces-0.2.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/path-pieces-0.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/path-pieces-0.2.1
hs-libraries: HSpath-pieces-0.2.1-Bpsfe2mCPCaEayXevejNMW
depends:
    base-4.11.1.0 text-1.2.3.0 time-1.8.0.2
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             text-1.2.3.0=5654b56910ce698015ec900075c28f62
             time-1.8.0.2=f5b6d28c2b89a17d60f5dfeda767abd0
haddock-interfaces: /usr/share/doc/haskell-path-pieces/html/path-pieces.haddock
haddock-html: /usr/share/doc/haskell-path-pieces/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
